local app = require("lapis").Application()
local babycode = require("lib.babycode")

local db = require("lapis.db")

local util = require("util")

local models = require("models")
local Users = models.Users

-- everything here requires a logged in moderator
app:before_filter(function(self)
  self.me = util.get_logged_in_user(self)
  if not self.me then
    self:write{redirect_to = self:url_for("all_topics")}
    return
  end

  if not self.me:is_mod() then
    self:write{redirect_to = self:url_for("all_topics")}
    return
  end
end)

app:get("user_list", "/list", function(self)
  self.users = Users:select("")

  return {render = "mod.user-list"}
end)

app:get("sort_topics", "/sort-topics", function(self)
  self.topics = db.query("SELECT * FROM topics ORDER BY sort_order ASC")
  self.page_title = "sorting topics"
  return {render = "mod.sort-topics"}
end)

app:post("sort_topics", "/sort-topics", function(self)
  local updates = self.params
  db.query("BEGIN")
  for topic_id, new_order in pairs(updates) do
    db.update("topics", {sort_order = new_order}, {id = topic_id})
  end
  db.query("COMMIT")
  return {redirect_to = self:url_for("sort_topics")}
end)

app:get("reparse_posts", "/reparse-posts", function(self)
  db.query("BEGIN")
  local hist = db.select("* FROM post_history")
  for _, history in ipairs(hist) do
    db.query(
      "UPDATE post_history SET content = ? WHERE post_history.id = ?",
      babycode.to_html(history.original_markup, require("lapis.html").escape),
      history.id
    )
  end
  db.query("COMMIT")
  return "ok"
end)

return app
